@@ -1,4 +1,4 @@
-/* r2ghidra- LGPL - Copyright 2019-2023 - thestr4ng3r, pancake */
+/* r2ghidra- LGPL - Copyright 2019-2025 - thestr4ng3r, pancake */
 
 #include "R2Architecture.h"
 #include "R2TypeFactory.h"
@@ -174,7 +174,7 @@ FunctionSymbol *R2Scope::registerFunction(RAnalFunction *fcn) const {
 	RList *vars = NULL;
 	
 	if (r_config_get_b (core->config, "r2ghidra.vars")) {
-		r_anal_var_all_list (core->anal, fcn);
+		vars = r_anal_var_all_list (core->anal, fcn);
 	}
 	auto stackSpace = arch->getStackSpace ();
 
@@ -183,8 +183,16 @@ FunctionSymbol *R2Scope::registerFunction(RAnalFunction *fcn) const {
 		case R_ANAL_VAR_KIND_BPV:
 		{
 			uintb off;
-			int delta = var->delta + fcn->bp_off - extraPop; // not 100% sure if extraPop is correct here
-			off = (delta >= 0)? delta: stackSpace->getHighest() + delta + 1;
+			// For arguments passed on stack, delta is positive (based on BP)
+			// For local variables, delta is negative
+			// The stack space coordinates are: 0 = return address, then arguments, then locals below
+			int delta = var->delta + fcn->bp_off - extraPop;
+			// Ensure we don't wrap around with incorrect offset calculation
+			if (delta >= 0) {
+				off = delta;
+			} else {
+				off = stackSpace->getHighest() + delta + 1;
+			}
 			return Address(stackSpace, off);
 		}
 		case R_ANAL_VAR_KIND_REG:
@@ -420,9 +428,29 @@ FunctionSymbol *R2Scope::registerFunction(RAnalFunction *fcn) const {
 	auto returnsymElement = child(prototypeElement, "returnsym");
 	childAddr (returnsymElement, "addr", returnAddr);
 
+#if R2_ABIVERSION >= 50
+	// Get return type from radare2 function signature if available
+	const char *ret_type = nullptr;
+	{
+		RCoreLock core_lock (arch->getCore ());
+		Sdb *tdb = core_lock->anal->sdb_types;
+		char *fname = r_type_func_guess (tdb, fcn_name);
+		if (fname && r_type_func_exist (tdb, fname)) {
+			ret_type = r_type_func_ret (tdb, fname);
+		}
+		free (fname);
+	}
+
+	// Use detected return type or fall back to default
+	const char *return_type_name = R_STR_ISNOTEMPTY (ret_type) ? ret_type : "uint";
+	child (returnsymElement, "typeref", {
+		{ "name", return_type_name }
+	});
+#else
 	child (returnsymElement, "typeref", {
 		{ "name", "uint" }
 	});
+#endif
 
 	child (&doc, "addr", {
 		{ "space", arch->getDefaultCodeSpace()->getName() },
